require 'spec_helper'

describe 'puppet_enterprise::console::service' do
  before :each do
    @facter_facts = {
      'osfamily'          => 'Debian',
      'operatingsystem'   => 'Debian',
      'lsbmajdistrelease' => '6',
      'puppetversion'     => '3.6.2 (Puppet Enterprise 3.3.0)',
      'is_pe'             => 'true',
      'fqdn'              => 'console.rspec',
      'clientcert'        => 'awesomecert',
      'pe_concat_basedir'    => '/tmp/file',
    }

    @params = { 'workers_only'  =>  false }
  end

  let(:facts) { @facter_facts }
  let(:params) { @params }

  describe 'managing both pe-puppet-dashboard-workers and pe-httpd' do
    it { should contain_service('pe-puppet-dashboard-workers') }
    it { should contain_service('pe-httpd') }
  end

  describe 'managing both pe-puppet-dashboard-workers and pe-httpd with workers_only as string false' do
    before :each do
      @params['workers_only'] = 'false'
    end
    it do
      expect {
        should compile
      }.to raise_error(Puppet::Error, /"false" is not a boolean.  It looks to be a String/)
    end
  end

  describe "managing only pe-puppet-dashboard-workers with workers_only as boolean true" do
    before :each do
      @params['workers_only'] = true
    end
    it { should contain_service('pe-puppet-dashboard-workers') }
    it { should_not contain_service('pe-httpd') }
  end
  describe "managing only pe-puppet-dashboard-workers with workers_only as string true" do
    before :each do
      @params['workers_only'] = 'true'
    end
    it do
      expect {
        should compile
      }.to raise_error(Puppet::Error, /"true" is not a boolean.  It looks to be a String/)
    end
  end
end
